gchecky.model.abstract_order_t

Package gchecky :: Module model :: Class abstract_order_t |
[hide private]
[frames] | no frames]

# Class abstract_order_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
                    abstract_order_t

Known Subclasses:
  add_merchant_order_number_t, add_tracking_data_t, archive_order_t, authorize_order_t, backorder_items_t, cancel_items_t, cancel_order_t, charge_order_t, deliver_order_t, process_order_t, refund_order_t, reset_items_shipping_information_t, return_items_t, send_buyer_message_t, ship_items_t, unarchive_order_t

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``-order``'`` The document's unique xml tag name.
| google_order_number = `ID:PATH(@google-order-number):REQ:EMPTY`
| _fields = ``{``'``google_order_number``'``:` ID:PATH(@google-order-number`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'google_order_number': ID:PATH(@google-order-number):REQ:EMPTY}